@@ -1,4 +1,4 @@
-// Copyright (c) 2004-2023 Intel Corporation
+// Copyright (c) 2004-2024 Intel Corporation
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -27,12 +27,6 @@
 #include "mfx_common.h"
 #include "mfx_common_decode_int.h"
 
-#ifdef MFX_ENABLE_JPEG_SW_FALLBACK
-#include "mfx_mjpeg_task.h"
-#include "umc_mjpeg_mfx_decode.h"
-#include "mfx_thread_task.h"
-#endif
-
 #include "mfx_enc_common.h"
 
 #include "umc_jpeg_frame_constructor.h"
@@ -86,7 +80,6 @@ public:
 
 private:
 
-    static bool IsNeedPartialAcceleration(VideoCORE * core, mfxVideoParam * par);
     static bool IsFormatSupport(mfxVideoParam * in);
 };
 
@@ -182,11 +175,7 @@ mfxStatus VideoDECODEMJPEG::Init(mfxVideoParam *par)
 
     if (MFX_PLATFORM_SOFTWARE == m_platform)
     {
-#ifdef MFX_ENABLE_JPEG_SW_FALLBACK
-        decoder.reset(new VideoDECODEMJPEGBase_SW);
-#else
         MFX_RETURN(MFX_ERR_UNSUPPORTED);
-#endif
     }
     else
     {
@@ -308,6 +297,9 @@ mfxStatus VideoDECODEMJPEG::QueryImplsDescription(
 
 mfxStatus VideoDECODEMJPEG::Reset(mfxVideoParam *par)
 {
+    TRACE_EVENT(MFX_TRACE_API_DECODE_RESET_TASK, EVENT_TYPE_START, TR_KEY_MFX_API, make_event_data(par ? par->mfx.FrameInfo.Width : 0,
+        par ? par->mfx.FrameInfo.Height : 0, par ? par->mfx.CodecId : 0));
+
     MFX_CHECK(m_isInit, MFX_ERR_NOT_INITIALIZED);
 
     MFX_CHECK_NULL_PTR1(par);
@@ -358,6 +350,8 @@ mfxStatus VideoDECODEMJPEG::Reset(mfxVideoParam *par)
         MFX_RETURN(MFX_WRN_PARTIAL_ACCELERATION);
     }
 
+    TRACE_EVENT(MFX_TRACE_API_DECODE_RESET_TASK, EVENT_TYPE_END, TR_KEY_MFX_API, make_event_data(MFX_ERR_NONE));
+
     return MFX_ERR_NONE;
 }
 
@@ -411,8 +405,8 @@ mfxStatus VideoDECODEMJPEG::GetVideoParam(mfxVideoParam *par)
 
         if (!par->mfx.FrameInfo.FrameRateExtD && !par->mfx.FrameInfo.FrameRateExtN)
         {
-            par->mfx.FrameInfo.FrameRateExtN = 30;
-            par->mfx.FrameInfo.FrameRateExtD = 1;
+            par->mfx.FrameInfo.FrameRateExtN = 0;
+            par->mfx.FrameInfo.FrameRateExtD = 0;
         }
     }
 
@@ -635,6 +629,8 @@ mfxStatus VideoDECODEMJPEG::QueryIOSurfInternal(VideoCORE *core, mfxVideoParam *
 
 mfxStatus VideoDECODEMJPEG::GetDecodeStat(mfxDecodeStat *stat)
 {
+    TRACE_EVENT(MFX_TRACE_API_DECODE_GETSTAT_TASK, EVENT_TYPE_START, TR_KEY_MFX_API, make_event_data(0));
+
     if (!m_isInit)
         MFX_RETURN(MFX_ERR_NOT_INITIALIZED);
 
@@ -644,6 +640,9 @@ mfxStatus VideoDECODEMJPEG::GetDecodeStat(mfxDecodeStat *stat)
     decoder->m_stat.NumError = 0;
 
     *stat = decoder->m_stat;
+
+    TRACE_EVENT(MFX_TRACE_API_DECODE_GETSTAT_TASK, EVENT_TYPE_END, TR_KEY_MFX_API, make_event_data(stat ? stat->NumFrame : 0, MFX_ERR_NONE));
+
     return MFX_ERR_NONE;
 }
 
@@ -722,7 +721,7 @@ mfxStatus VideoDECODEMJPEG::DecodeFrameCheck(mfxBitstream *bs, mfxFrameSurface1
                                                     (MFX_PICSTRUCT_FIELD_TFF));
         (*surface_out)->Data.TimeStamp = GetMfxTimeStamp(dst->GetTime());
 
-        if(MFX_TIME_STAMP_INVALID == (*surface_out)->Data.TimeStamp)
+        if ((MFX_TIME_STAMP_INVALID == (*surface_out)->Data.TimeStamp) && m_vPar.mfx.FrameInfo.FrameRateExtN)
         {
             (*surface_out)->Data.TimeStamp = ((mfxU64)m_frameOrder * m_vPar.mfx.FrameInfo.FrameRateExtD * MFX_TIME_STAMP_FREQUENCY) / m_vPar.mfx.FrameInfo.FrameRateExtN;
         }
@@ -920,15 +919,19 @@ mfxStatus VideoDECODEMJPEG::GetUserData(mfxU8 *ud, mfxU32 *sz, mfxU64 *ts)
 
 mfxStatus VideoDECODEMJPEG::GetPayload( mfxU64 *ts, mfxPayload *payload )
 {
+    TRACE_EVENT(MFX_TRACE_API_DECODE_GETPAYLOAD_TASK, EVENT_TYPE_START, TR_KEY_MFX_API, make_event_data(payload));
     if (!m_isInit)
         MFX_RETURN(MFX_ERR_NOT_INITIALIZED);
 
     MFX_CHECK_NULL_PTR3(ts, payload, payload->Data);
+    TRACE_EVENT(MFX_TRACE_API_DECODE_GETPAYLOAD_TASK, EVENT_TYPE_END, TR_KEY_MFX_API, make_event_data(MFX_ERR_UNSUPPORTED));
+
     MFX_RETURN(MFX_ERR_UNSUPPORTED);
 }
 
 mfxStatus VideoDECODEMJPEG::SetSkipMode(mfxSkipMode mode)
 {
+    TRACE_EVENT(MFX_TRACE_API_DECODE_SETSKIPMODE_TASK, EVENT_TYPE_START, TR_KEY_MFX_API, make_event_data(mode));
     // check error(s)
     if (!m_isInit)
     {
@@ -958,6 +961,7 @@ mfxStatus VideoDECODEMJPEG::SetSkipMode(mfxSkipMode mode)
         m_skipRate = 0;
         break;
     }
+    TRACE_EVENT(MFX_TRACE_API_DECODE_SETSKIPMODE_TASK, EVENT_TYPE_END, TR_KEY_MFX_API, make_event_data(MFX_ERR_NONE));
 
     return MFX_ERR_NONE;
 
@@ -1030,90 +1034,6 @@ bool VideoDECODEMJPEG::IsSameVideoParam(mfxVideoParam * newPar, mfxVideoParam *
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////
 // MFX_JPEG_Utility implementation
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////
-bool MFX_JPEG_Utility::IsNeedPartialAcceleration(VideoCORE * core, mfxVideoParam * par)
-{
-    if (!par)
-        return false;
-
-    if (par->mfx.JPEGColorFormat == MFX_JPEG_COLORFORMAT_RGB &&
-        par->mfx.JPEGChromaFormat != MFX_CHROMAFORMAT_YUV444)
-        return true;
-
-
-    switch (par->mfx.FrameInfo.FourCC)
-    {
-        case MFX_FOURCC_NV12:
-            if (par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV420        ||
-                par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV444        ||
-                par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV422H       ||
-                par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV422V       ||
-                par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV411        ||
-                par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_MONOCHROME)
-                return false;
-            else
-                return true;
-        case MFX_FOURCC_YUY2:
-            if (par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV420       ||
-                par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV422H      ||
-                par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV422V      ||
-                par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_MONOCHROME   ||
-                par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV444)
-                return false;
-            else
-                return true;
-        case MFX_FOURCC_UYVY:
-            if( par->mfx.JPEGColorFormat == MFX_JPEG_COLORFORMAT_YCbCr &&
-               (par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV420 || par->mfx.JPEGChromaFormat == MFX_CHROMAFORMAT_YUV422H)
-              ) return false;
-            else
-                return true;
-        case MFX_FOURCC_RGB4:
-            if (par->mfx.JPEGColorFormat == MFX_JPEG_COLORFORMAT_RGB && par->mfx.JPEGChromaFormat != MFX_CHROMAFORMAT_YUV444)
-                return true;
-            else
-                return false;
-        case MFX_FOURCC_YUV400:
-            if (par->mfx.JPEGColorFormat == MFX_JPEG_COLORFORMAT_YCbCr && par->mfx.JPEGChromaFormat != MFX_CHROMAFORMAT_YUV400)
-                return true;
-            else
-                return false;
-        case MFX_FOURCC_YUV411:
-            if (par->mfx.JPEGColorFormat == MFX_JPEG_COLORFORMAT_YCbCr && par->mfx.JPEGChromaFormat != MFX_CHROMAFORMAT_YUV411)
-                return true;
-            else
-                return false;
-        case MFX_FOURCC_YUV422V:
-            if (par->mfx.JPEGColorFormat == MFX_JPEG_COLORFORMAT_YCbCr && par->mfx.JPEGChromaFormat != MFX_CHROMAFORMAT_YUV422V)
-                return true;
-            else
-                return false;
-        case MFX_FOURCC_YUV422H:
-            if (par->mfx.JPEGColorFormat == MFX_JPEG_COLORFORMAT_YCbCr && par->mfx.JPEGChromaFormat != MFX_CHROMAFORMAT_YUV422H)
-                return true;
-            else
-                return false;
-        case MFX_FOURCC_IMC3:
-            if (par->mfx.JPEGColorFormat == MFX_JPEG_COLORFORMAT_YCbCr && par->mfx.JPEGChromaFormat != MFX_CHROMAFORMAT_YUV420)
-                return true;
-            else
-                return false;
-        case MFX_FOURCC_YUV444:
-            if (par->mfx.JPEGColorFormat == MFX_JPEG_COLORFORMAT_YCbCr && par->mfx.JPEGChromaFormat != MFX_CHROMAFORMAT_YUV444)
-                return true;
-            else
-                return false;
-        case MFX_FOURCC_RGBP:
-        case MFX_FOURCC_BGRP:
-            if (par->mfx.JPEGColorFormat == MFX_JPEG_COLORFORMAT_RGB && par->mfx.JPEGChromaFormat != MFX_CHROMAFORMAT_YUV444)
-                return true;
-            else
-                return false;
-        default:
-            return true;
-    }
-
-    return false;
-}
 
 eMFXPlatform MFX_JPEG_Utility::GetPlatform(VideoCORE * core, mfxVideoParam * par)
 {
@@ -1159,8 +1079,12 @@ bool MFX_JPEG_Utility::IsFormatSupport(mfxVideoParam * in)
     bool support = false;
 
     mfxU32 fourCC = in->mfx.FrameInfo.FourCC;
-    mfxU16 chromaFormat = in->mfx.FrameInfo.ChromaFormat;
+    mfxU16 chromaFormat = in->mfx.JPEGChromaFormat;
     mfxU16 colorFormat  = in->mfx.JPEGColorFormat;
+
+    if (colorFormat == MFX_JPEG_COLORFORMAT_RGB && chromaFormat != MFX_CHROMAFORMAT_YUV444)
+        return support;
+
     switch (chromaFormat)
     {
     case MFX_CHROMAFORMAT_MONOCHROME:
@@ -1513,6 +1437,9 @@ VideoDECODEMJPEGBase::VideoDECODEMJPEGBase()
 
 mfxStatus VideoDECODEMJPEGBase::GetVideoParam(mfxVideoParam *par, UMC::MJPEGVideoDecoderBaseMFX * mjpegDecoder)
 {
+    TRACE_EVENT(MFX_TRACE_API_DECODE_GETVIDEOPARAM_TASK, EVENT_TYPE_START, TR_KEY_MFX_API, make_event_data(par ? par->mfx.FrameInfo.Width : 0,
+        par ? par->mfx.FrameInfo.Height : 0, par ? par->mfx.CodecId : 0));
+
     mfxExtJPEGQuantTables*    jpegQT = (mfxExtJPEGQuantTables*)   mfx::GetExtBuffer( par->ExtParam, par->NumExtParam, MFX_EXTBUFF_JPEG_QT );
     mfxExtJPEGHuffmanTables*  jpegHT = (mfxExtJPEGHuffmanTables*) mfx::GetExtBuffer( par->ExtParam, par->NumExtParam, MFX_EXTBUFF_JPEG_HUFFMAN );
 
@@ -1535,6 +1462,8 @@ mfxStatus VideoDECODEMJPEGBase::GetVideoParam(mfxVideoParam *par, UMC::MJPEGVide
             return ConvertUMCStatusToMfx(umcRes);
     }
 
+    TRACE_EVENT(MFX_TRACE_API_DECODE_GETVIDEOPARAM_TASK, EVENT_TYPE_END, TR_KEY_MFX_API, make_event_data(MFX_ERR_NONE));
+
     return MFX_ERR_NONE;
 }
 
@@ -2101,237 +2030,4 @@ mfxStatus VideoDECODEMJPEGBase_HW::CompleteTask(void *pParam, mfxStatus )
     return MFX_ERR_NONE;
 }
 
-#ifdef MFX_ENABLE_JPEG_SW_FALLBACK
-VideoDECODEMJPEGBase_SW::VideoDECODEMJPEGBase_SW()
-{
-    pLastTask = NULL;
-    m_tasksCount = 0;
-}
-
-mfxStatus VideoDECODEMJPEGBase_SW::Init(mfxVideoParam *decPar, mfxFrameAllocRequest *, mfxFrameAllocResponse *, mfxFrameAllocRequest *, bool, VideoCORE *)
-{
-#if !defined(MSDK_USE_EXTERNAL_IPP)
-    auto ippSt = MfxIppInit();
-    MFX_CHECK(ippSt == ippStsNoErr, MFX_ERR_UNSUPPORTED);
-#endif
-
-    ConvertMFXParamsToUMC(decPar, &umcVideoParams);
-    umcVideoParams.numThreads = m_vPar.mfx.NumThread;
-    return MFX_ERR_NONE;
-}
-
-mfxStatus VideoDECODEMJPEGBase_SW::Reset(mfxVideoParam *par)
-{
-    m_tasksCount = 0;
-    pLastTask = nullptr;
-    {
-        std::lock_guard<std::mutex> guard(m_guard);
-        while(!m_freeTasks.empty())
-        {
-            m_freeTasks.pop();
-        }
-    }
-
-    memset(&m_stat, 0, sizeof(mfxDecodeStat));
-    m_vPar = *par;
-
-    UMC::Status umcSts = m_surface_source->Reset();
-    MFX_CHECK(umcSts == UMC::UMC_OK, MFX_ERR_MEMORY_ALLOC);
-
-    return MFX_ERR_NONE;
-}
-
-mfxStatus VideoDECODEMJPEGBase_SW::Close()
-{
-    m_tasksCount = 0;
-    pLastTask = nullptr;
-    memset(&m_stat, 0, sizeof(mfxDecodeStat));
-
-    // delete free tasks queue
-    {
-        std::lock_guard<std::mutex> guard(m_guard);
-        while (!m_freeTasks.empty())
-        {
-            m_freeTasks.pop();
-        }
-    }
-
-    UMC::Status umcSts = m_surface_source->Close();
-    MFX_CHECK(umcSts == UMC::UMC_OK, ConvertUMCStatusToMfx(umcSts));
-
-    return MFX_ERR_NONE;
-}
-
-mfxStatus VideoDECODEMJPEGBase_SW::GetVideoParam(mfxVideoParam *par)
-{
-    mfxExtJPEGQuantTables*    jpegQT = (mfxExtJPEGQuantTables*)   mfx::GetExtBuffer( par->ExtParam, par->NumExtParam, MFX_EXTBUFF_JPEG_QT );
-    mfxExtJPEGHuffmanTables*  jpegHT = (mfxExtJPEGHuffmanTables*) mfx::GetExtBuffer( par->ExtParam, par->NumExtParam, MFX_EXTBUFF_JPEG_HUFFMAN );
-
-    if(!jpegQT && !jpegHT)
-        return MFX_ERR_NONE;
-
-    MFX_CHECK(pLastTask, MFX_ERR_UNSUPPORTED);
-
-    return VideoDECODEMJPEGBase::GetVideoParam(par, pLastTask->m_pMJPEGVideoDecoder.get());
-}
-
-mfxStatus VideoDECODEMJPEGBase_SW::ReserveUMCDecoder(UMC::MJPEGVideoDecoderBaseMFX* &pMJPEGVideoDecoder, mfxFrameSurface1 *surf)
-{
-    pMJPEGVideoDecoder = 0;
-    MFX_SAFE_CALL(m_surface_source->SetCurrentMFXSurface(surf));
-
-    pMJPEGVideoDecoder = m_freeTasks.front()->m_pMJPEGVideoDecoder.get();
-    //pMJPEGVideoDecoder->Reset();
-    return MFX_ERR_NONE;
-}
-
-void VideoDECODEMJPEGBase_SW::ReleaseReservedTask()
-{
-    if (!m_freeTasks.empty())
-        m_freeTasks.front()->Reset();
-}
-
-mfxStatus VideoDECODEMJPEGBase_SW::AddPicture(UMC::MediaDataEx *pSrcData, mfxU32 & numPic)
-{
-    // select the field position. 0 means top, 1 means bottom.
-    mfxU32 fieldPos = m_freeTasks.front()->NumPicCollected();
-
-    if (MFX_PICSTRUCT_FIELD_BFF == m_vPar.mfx.FrameInfo.PicStruct)
-    {
-        // change field order in BFF case
-        fieldPos ^= 1;
-    }
-
-    // add picture to the task
-    MFX_SAFE_CALL(m_freeTasks.front()->AddPicture(pSrcData, fieldPos));
-    numPic = m_freeTasks.front()->NumPicCollected();
-    return MFX_ERR_NONE;
-}
-
-mfxStatus VideoDECODEMJPEGBase_SW::FillEntryPoint(MFX_ENTRY_POINT *pEntryPoint, mfxFrameSurface1 *surface_work, mfxFrameSurface1 *surface_out)
-{
-    // remove the ready task from the queue
-    {
-        std::lock_guard<std::mutex> guard(m_guard);
-        pLastTask = m_freeTasks.front().release();
-        m_freeTasks.pop();
-    }
-
-    pLastTask->surface_work = surface_work;
-    pLastTask->surface_out = surface_out;
-
-    pEntryPoint->requiredNumThreads = std::min(pLastTask->m_pMJPEGVideoDecoder->NumDecodersAllocated(),
-                                               pLastTask->NumPiecesCollected());
-    pEntryPoint->pParam = pLastTask;
-
-    return MFX_ERR_NONE;
-}
-
-mfxStatus VideoDECODEMJPEGBase_SW::AllocateFrameData(UMC::FrameData *&data)
-{
-    CJpegTask *pTask = m_freeTasks.front().get();
-
-    // prepare the decoder(s)
-    UMC::Status umcRes = pTask->m_pMJPEGVideoDecoder->AllocateFrame();
-    if (UMC::UMC_OK != umcRes)
-    {
-        return ConvertUMCStatusToMfx(umcRes);
-    }
-
-    // save parameters to the task
-    pTask->dst = pTask->m_pMJPEGVideoDecoder.get()->GetDst();
-
-    UMC::FrameData *dst = m_freeTasks.front()->dst;
-    dst->SetTime(m_freeTasks.front()->GetPictureBuffer(0).timeStamp);
-    data = dst;
-    return MFX_ERR_NONE;
-}
-
-mfxStatus VideoDECODEMJPEGBase_SW::CheckTaskAvailability(mfxU32 maxTaskNumber)
-{
-    if (m_freeTasks.empty())
-    {
-        if (m_tasksCount >= maxTaskNumber)
-        {
-            return MFX_WRN_DEVICE_BUSY;
-        }
-
-        std::unique_ptr<CJpegTask> pTask(new CJpegTask());
-        m_tasksCount++;
-
-        // initialize the task
-        MFX_SAFE_CALL(pTask->Initialize(umcVideoParams,
-                                        m_surface_source.get(),
-                                        m_vPar.mfx.Rotation,
-                                        m_vPar.mfx.JPEGChromaFormat,
-                                        m_vPar.mfx.JPEGColorFormat));
-
-        // save the task object into the queue
-        {
-            std::lock_guard<std::mutex> guard(m_guard);
-            m_freeTasks.push(std::move(pTask));
-        }
-    }
-
-    return MFX_ERR_NONE;
-}
-
-mfxStatus VideoDECODEMJPEGBase_SW::RunThread(void *pParam, mfxU32 threadNumber, mfxU32 callNumber)
-{
-    CJpegTask *task = (CJpegTask *) pParam;
-    if (!task)
-        MFX_RETURN(MFX_ERR_NULL_PTR);
-
-    // check the number of call. one call = one piece decoded. all extra call
-    // should go exit.
-    if (callNumber >= task->NumPiecesCollected())
-    {
-        return MFX_TASK_DONE;
-    }
-
-    // do decoding process
-    UMC::Status umcSts = task->m_pMJPEGVideoDecoder->DecodePicture(*task, threadNumber, callNumber);
-    MFX_CHECK(umcSts == UMC::UMC_OK, MFX_ERR_INVALID_VIDEO_PARAM);
-
-    return ((callNumber + 1) == task->NumPiecesCollected()) ? (MFX_TASK_DONE) : (MFX_TASK_WORKING);
-}
-
-mfxStatus VideoDECODEMJPEGBase_SW::CompleteTask(void *pParam, mfxStatus taskRes)
-{
-    CJpegTask &task = *((CJpegTask *) pParam);
-
-    // do color conversion and other useless stuff
-    if (MFX_ERR_NONE == taskRes)
-    {
-        UMC::Status umcRes = UMC::UMC_OK;
-
-        umcRes = task.m_pMJPEGVideoDecoder->PostProcessing(task.GetPictureBuffer(0).timeStamp);
-        if (UMC::UMC_OK != umcRes)
-        {
-            return ConvertUMCStatusToMfx(umcRes);
-        }
-
-        // decoding is ready. prepare to output:
-        mfxStatus mfxSts = m_surface_source->PrepareToOutput(task.surface_out,
-                                                                    task.dst->GetFrameMID(),
-                                                                    &m_vPar, mfxU32(~MFX_COPY_USE_VACOPY_ANY));
-        if (mfxSts < MFX_ERR_NONE)
-        {
-            return mfxSts;
-        }
-
-        task.m_pMJPEGVideoDecoder->CloseFrame();
-
-        m_stat.NumFrame++;
-    }
-
-    task.Reset();
-    {
-        std::lock_guard<std::mutex> guard(m_guard);
-        m_freeTasks.emplace(&task);
-    }
-    return MFX_ERR_NONE;
-}
-#endif //ifdef MFX_ENABLE_JPEG_SW_FALLBACK
-
 #endif // MFX_ENABLE_MJPEG_VIDEO_DECODE
\ No newline at end of file
