@@ -1432,9 +1432,10 @@ UMC::Status TaskSupplier_H265::DecodeHeaders(UMC::MediaDataEx *nalUnit)
         NalUnitType nal_unit_type;
         uint32_t temporal_id = 0;
 
-        bitStream.GetNALUnitType(nal_unit_type, temporal_id);
-
-        switch(nal_unit_type)
+        umcRes = bitStream.GetNALUnitType(nal_unit_type, temporal_id);
+        if (umcRes != UMC::UMC_OK)
+            return umcRes;
+        switch (nal_unit_type)
         {
         case NAL_UT_VPS:
             umcRes = xDecodeVPS(&bitStream);
@@ -1870,16 +1871,7 @@ UMC::Status TaskSupplier_H265::AddOneFrame(UMC::MediaData * pSource)
                         {
                             int32_t nalIndex = pMediaDataEx->index;
                             int32_t size = pMediaDataEx->offsets[nalIndex + 1] - pMediaDataEx->offsets[nalIndex];
-
-                            auto frame_source = dynamic_cast<SurfaceSource*>(m_pFrameAllocator);
-                            if (frame_source && frame_source->GetSurfaceType() && !m_RecreateSurfaceFlag)
-                            {
-                                m_checkCRAInsideResetProcess = false;
-                            }
-                            else
-                            {
-                                m_checkCRAInsideResetProcess = true;
-                            }
+                            m_checkCRAInsideResetProcess = true;
 
                             if (AddSlice(0, !pSource) == UMC::UMC_OK)
                             {
@@ -2313,10 +2305,10 @@ UMC::Status TaskSupplier_H265::AddSlice(H265Slice * pSlice, bool )
             !IsPictureTheSame(firstSlice, pSlice);
         if (changed)
         {
+            m_pLastSlice = pSlice;
             CompleteFrame(view.pCurFrame);
             OnFullFrame(view.pCurFrame);
             view.pCurFrame = NULL;
-            m_pLastSlice = pSlice;
             return UMC::UMC_OK;
         }
     }
